' *MATLAB / Data Exchange
' !!! Do not change the line above !!!
'
'--------------------------------------------------------------------------------------------
' Macro to interface with Matlab.  Illustrative example, showing how to use COM/ActiveX 
' objects to exchange data with Matlab and MWS.  This example sends S11 Linear to Matlab and
' computes S11 in dB within Matlab.  The macro then retrieves the data and plots it in MWS.
'
' sws 9/2002
'--------------------------------------------------------------------------------------------
Option Explicit

Sub Main

    'User defined settings
    Dim matlab_visible As Boolean
    Dim user_path, save_file_name As String 
    matlab_visible = True 				'True to keep Matlab command window open, False to not display it
    user_path = "C:\Program Files\CST MicroWave Studio 5.1"	'path that Matlab opens to and any data is saved to
    save_file_name = "cst_data"						    	'name of .mat file matlab saves all data to

    'variable defn
    '------------------------------------------------------------------------------------
    'Matlab variables
	Dim matlab As Object
	Dim Result As String
	'set up variables
	Dim NumPorts, NumModes As Integer
	Dim factorA As Double
	Dim i, j, NumFreq As Integer
	Dim data_save As Boolean	
	Dim fileA As String
	'Result variables
	Dim S11A As Object
	Dim freq() As Double
	Dim S11B() As Double
	Dim S11dB() As Double
	Dim MImag() As Double

	'MWS problem information
	NumPorts = Solver.GetNumberOfPorts
	NumModes = Solver.GetNumberOfPorts
	factorA = Units.GetFrequencySIToUnit
 
    'Retrieve MWS data 
    '------------------------------------------------------------------------------------
    Set S11A = Result1D("a1(1)1(1)") 
    NumFreq = Solver.GetNFsteps
    ReDim S11B(NumFreq-1)
    ReDim freq(NumFreq-1)
    ReDim S11dB(NumFreq-1)
    For j = 0 To NumFreq-1
    	freq(j) = S11A.GetX(j)/factorA
    	S11B(j) = S11A.GetY(j)
    Next j
	 
	'Matlab COM/ActiveX interaction
	'------------------------------------------------------------------------------------
	'1) create COM object and initiate Matlab as an activeX server
    Set matlab = CreateObject("Matlab.Application")  
    If matlab_visible Then 
       Result = matlab.Execute("h=actxserver('Matlab.Application');set(h,'visible',1);")
    End If
    '2) send all MWS data to Matlab using Automation methods (see app note for listing)
    Call matlab.PutCharArray("user_path","base",user_path)
    Call matlab.PutCharArray("save_file_name","base",save_file_name)
    Call matlab.PutFullMatrix("S11","base",S11B,MImag)
    Call matlab.PutFullMatrix("freq","base",freq,MImag)
    '3) use execute command to control Matlab engine
    Result = matlab.Execute("cd(user_path)")
    Result = matlab.Execute("S11dB=20.*log10(abs(S11));")
    Result = matlab.Execute("plot(freq,S11dB);grid on;")
    Result = matlab.Execute("title('S-parameters from CST Microwave Studio');")
    Result = matlab.Execute("xlabel('Freq, GHz.');")
    Result = matlab.Execute("ylabel('S11, dB');")
    Result = matlab.Execute("eval(['save ',save_file_name,';']);")
    '4) retreive all data from Matlab to display in MWS
    Call matlab.GetFullMatrix("S11dB","base",S11dB,MImag)
    
    'display or store Matlab data in MWS form
    '------------------------------------------------------------------------------------
    '1) write any data you wish to display to a file
    fileA = "matlab_output.txt"
    Open fileA For Output As #1
    For j = 0 To NumFreq-1
    	Print #1,CStr(freq(j)) & "   " & CStr(S11dB(j))	
    Next j
    Close #1
    '2) insert Matlab data into result tree
   	With ResultTree
		.Reset
		.Name "1D Results\Matlab\S11 dB"
		.Type "XYSignal"
		.Subtype "Linear"
		.Title "S11 in dB computed in Matlab"
		.Xlabel "Frequency, Hz" 
		.Ylabel "dB"
		.File fileA
		.Add
	End With
            
End Sub

