' *MATLAB / Time Window
' !!! Do not change the line above !!!
'
'--------------------------------------------------------------------------------------------
' Macro to interface with Matlab.  Goal of macro is to recompute the transforms (FFT) of time
' signals from simulations, allowing an user to investigate the effect of the accuracy setting 
' on resulting S-parameters.  Macro interacts with Matlab using COM and ActiveX objects.  
' This is a demonstration version and as such is written for a one port strucutre.  The FFT 
' routine employed can be greatly improved with respect to it's padding scheme.  Please see 
' accompying .m files for details.
'
' Macro calls several MATLAB .m files (calc_sparm.m, matlab_fft.m, nearest.m,energy_plot.m) which
' must be in the user_path to accesible.  default of user_path is 
' C:\Program Files\CST MicroWave Studio 5.1\Macros 
' 
'
' sws 9/2002
'--------------------------------------------------------------------------------------------
Option Explicit

Sub Main

    'User defined settings
    Dim matlab_visible As Boolean
    Dim user_path, save_file_name As String
    matlab_visible = True 							'True to keep Matlab command window open, False to not display it
    user_path = "C:\Program Files\CST MicroWave Studio 5.1\Macros"	'path that Matlab opens to and any data is saved to
    save_file_name = "cst_data"						'name of .mat file matlab saves all data to
    
    'variable defn
    '------------------------------------------------------------------------------------
    'Matlab variables
	Dim matlab As Object
	Dim Result As String
	Dim sendA(2) As Double 

	'set up variables
	Dim NumPorts, NumModes, NumFreq, NumEng, NumTime As Integer
	Dim factorA, factorB As Double
	Dim j, i As Integer
	
	'Result variables
	Dim eng_obj, sig_in_obj, sig_out_obj As Object
	Dim file_nameA As String
	Dim freqs() As Double
	Dim times() As Double
	Dim eng_time() As Double
	Dim eng_A() As Double
	Dim T_stop As Double
	Dim sig_in() As Double
	Dim sig_out() As Double
	Dim MImag() As Double
	Dim NumSamp As Integer
	Dim Fmin, Fmax As Double
	Dim S11dBD() As Double
	Dim freqD() As Double
		
	'MWS problem information
	NumPorts = Solver.GetNumberOfPorts
	NumModes = Solver.GetNumberOfPorts
	factorA = Units.GetFrequencyUnitToSI
	factorB = Units.GetTimeUnitToSI
	NumSamp = Solver.GetNFsteps
	Fmin = Solver.GetFmin
	Fmax = Solver.GetFmax
 
    'Retrieve MWS data 
    '-----------------------------------------------------------------------------------
    Set eng_obj = energy_file_load("1")
    NumEng = eng_obj.GetN
    ReDim eng_A(NumEng-1)
    ReDim eng_time(NumEng-1)
    For j = 0 To NumEng-1
    	eng_time(j) = eng_obj.GetX(j)*factorB
    	eng_A(j) = eng_obj.GetY(j)
    Next j
    
    Set sig_in_obj = Result1D("i1(1)")
    NumTime = sig_in_obj.GetN
    ReDim times(NumTime-1)
    ReDim sig_in(NumTime-1)
    For j=0 To NumTime-1
    	times(j) = sig_in_obj.GetX(j)*factorB
    	sig_in(j) = sig_in_obj.GetY(j)
	Next j
    	
    Set sig_out_obj = Result1D("o1(1)1(1)")
    ReDim sig_out(NumTime-1)
    For j=0 To NumTime-1
    	sig_out(j) = sig_out_obj.GetY(j)
	Next j
	 
	'Matlab COM/ActiveX interaction
	'------------------------------------------------------------------------------------
	'1) create COM object and initiate Matlab as an activeX server
    Set matlab = CreateObject("Matlab.Application")  
    If matlab_visible Then 
    	Result = matlab.Execute("h=actxserver('Matlab.Application');set(h,'visible',1);")
    End If
    '2) send all MWS data to Matlab using Automation methods (see app note for listing)
    Call matlab.PutCharArray("user_path","base",user_path)
    Call matlab.PutCharArray("save_file_name","base",save_file_name)
    Call matlab.PutFullMatrix("energy","base",eng_A,MImag)
    Call matlab.PutFullMatrix("eng_time","base",eng_time,MImag)
    Call matlab.PutFullMatrix("sig_in","base",sig_in,MImag)
    Call matlab.PutFullMatrix("sig_out","base",sig_out,MImag)
	Call matlab.PutFullMatrix("time","base",times,MImag)
    sendA(0) = NumSamp
    sendA(1) = Fmin * factorA
    sendA(2) = Fmax * factorA
    Call matlab.PutFullMatrix("sendA","base",sendA,MImag)
    '3) use Execute Command To control matlab engine
    'use .m files for ease of use, note that .m files must be in user_path or linked at startup!
    Result = matlab.Execute("cd(user_path);")
    Result = matlab.Execute("energy_plot;")
    Result = matlab.Execute("calc_sparm;")
    '4) retreive all data from Matlab to display in MWS
    ReDim S11dBD(NumSamp-1)
    ReDim freqD(NumSamp-1)
    Call matlab.GetFullMatrix("S11dBD","base",S11dBD,MImag)
    Call matlab.GetFullMatrix("freqD","base",freqD,MImag)
    
    'display or store Matlab data in MWS form
    '------------------------------------------------------------------------------------
    '1) write any data you wish to display to a file
    file_nameA = "matlab_output.txt"
    Open file_nameA For Output As #1
    For j = 0 To NumSamp-1
    	Print #1,CStr(freqD(j)/factorA) & "   " & CStr(S11dBD(j))	
    Next j
    Close #1
   ' '2) insert Matlab data into result tree
    With ResultTree
		.Reset
		.Name "1D Results\Matlab\S11 dB"
'        .Name "1D Results\|S| dB\Matlab S11 dB"
		.Type "XYSignal"
		.Subtype "linear"
		.Title "S11 in dB computed in Matlab"
		.Xlabel "Frequency, GHz" 
		.Ylabel "dB"
		.File file_nameA
		.Add
	End With
            
End Sub

Private Function energy_file_load (file_nameA As String) As Object
' function accepts a string indicating which energy file to load.  
' returns an object which holds the data in the specified energy file.

		'variable defn
        Dim base_nameA As String
        Dim indA As Integer
        
		'rename .eng file to .sig for easy loading
		base_nameA = GetProjectBaseName
		FileCopy base_nameA & "^" & file_nameA & ".eng", base_nameA & "^" & file_nameA & "eng.sig" 
		
		'set new energy file to an object
		Set energy_file_load = Result1D(file_nameA & "eng")

End Function

