'# MWS Version: V 4.0 - Aug 30 2002 - 17:10:43

'@ use template: Antenna (on Planar Substrate)

' Template for Antenna on Planar Substrate
' ========================================
' set units to mm, ghz
With Units 
     .Geometry "mm" 
     .Frequency "ghz" 
     .Time "ns" 
End With 
' set background material to vacuum
With Background 
     .Type "Normal" 
     .Epsilon "1.0" 
     .Mue "1.0" 
     .XminSpace "0.0" 
     .XmaxSpace "0.0" 
     .YminSpace "0.0" 
     .YmaxSpace "0.0" 
     .ZminSpace "0.0" 
     .ZmaxSpace "0.0" 
End With 
' set boundary conditions to open, zmin to electric
With Boundary
     .Xmin "expanded open" 
     .Xmax "expanded open" 
     .Ymin "expanded open" 
     .Ymax "expanded open" 
     .Zmin "electric" 
     .Zmax "expanded open" 
     .Xsymmetry "none" 
     .Ysymmetry "none" 
     .Zsymmetry "none" 
End With
' optimize mesh settings for planar structures
With Mesh 
     .MergeThinPECLayerFixpoints "True" 
     .RatioLimit "50" 
End With

'@ define background

With Background 
     .Type "Normal" 
     .Epsilon "1.0" 
     .Mue "1.0" 
     .XminSpace "0.0" 
     .XmaxSpace "0.0" 
     .YminSpace "0.0" 
     .YmaxSpace "0.0" 
     .ZminSpace "0.0" 
     .ZmaxSpace "8" 
End With

'@ define cylinder: PEC:solid1

With Cylinder 
     .Reset 
     .Name "solid1" 
     .Layer "PEC" 
     .OuterRadius "17" 
     .InnerRadius "0" 
     .Axis "z" 
     .Zrange "0", "0.05" 
     .Xcenter "0" 
     .Ycenter "0" 
     .Create 
End With

'@ activate local coordinates

WCS.ActivateWCS "local"

'@ move wcs

WCS.MoveWCS "local", "0.0", "0.0", "-1.59"

'@ define brick: PEC:solid2

With Brick
     .Reset 
     .Name "solid2" 
     .Layer "PEC" 
     .Xrange "-2", "2" 
     .Yrange "-56", "0" 
     .Zrange "0", "0.05" 
     .Create
End With

'@ store picked point: 1

Pick.NextPickToDatabase "1" 
Pick.PickMidpointFromId "PEC:solid2", "6"

'@ store picked point: 2

Pick.NextPickToDatabase "2" 
Pick.PickCirclecenterFromId "PEC:solid1", "2"

'@ store picked point: 3

Pick.NextPickToDatabase "3" 
Pick.PickCirclecenterFromId "PEC:solid1", "2"

'@ define layer: Substrate

With Layer
     .Reset 
     .Name "Substrate"
     .FrqType "hf" 
     .Type "Normal" 
     .Epsilon "2.62" 
     .Mue "1.0" 
     .Kappa "0.0" 
     .TanD "0.0" 
     .TanDFreq "0.0" 
     .TanDGiven "False" 
     .TanDModel "ConstTanD" 
     .KappaM "0.0" 
     .TanDM "0.0" 
     .TanDMFreq "0.0" 
     .TanDMGiven "False" 
     .DispModelEps "None" 
     .DispModelMue "None" 
     .Rho "0.0" 
     .Colour "0", "0.501961", "1" 
     .Wireframe "False" 
     .Transparency "25" 
     .Create
End With

'@ define brick: Substrate:solid3

With Brick
     .Reset 
     .Name "solid3" 
     .Layer "Substrate" 
     .Xrange "xp(1) - 0.5*(75.8)", "xp(1) + 0.5*(75.8)" 
     .Yrange "yp(1)", "yp(2)+35.5" 
     .Zrange "-1.59", "zp(2)" 
     .Create
End With

'@ boolean insert shapes: Substrate:solid3, PEC:solid1

Solid.Insert "Substrate:solid3", "PEC:solid1"

'@ boolean insert shapes: Substrate:solid3, PEC:solid2

Solid.Insert "Substrate:solid3", "PEC:solid2"

'@ define boundaries

With Boundary
     .Xmin "open" 
     .Xmax "open" 
     .Ymin "open" 
     .Ymax "open" 
     .Zmin "electric" 
     .Zmax "open" 
     .Xsymmetry "magnetic" 
     .Ysymmetry "none" 
     .Zsymmetry "none" 
End With

'@ define automesh state

Mesh.Automesh "True"

'@ define frequency range

Solver.FrequencyRange "0", "5"

'@ define port: 1

With Port 
     .Reset 
     .PortNumber "1" 
     .NumberOfModes "1" 
     .AdjustPolarization False 
     .PolarizationAngle "0.0" 
     .ReferencePlaneDistance "yp(1)-yp(0)+17" 
     .TextSize "50" 
     .Coordinates "Free" 
     .Location "ymin" 
     .Xrange "-8", "8" 
     .Zrange "-3.18", "3" 
     .Create 
End With

'@ define monitor: h-field (f=2.92)

With Monitor 
     .Reset 
     .Name "h-field (f=2.92)" 
     .Dimension "Volume" 
     .Domain "Frequency" 
     .FieldType "Hfield" 
     .Frequency "2.92" 
     .Create 
End With

'@ define farfield monitor: farfield (f=2.92)

With Monitor 
     .Reset 
     .Name "farfield (f=2.92)" 
     .Domain "Frequency" 
     .FieldType "Farfield" 
     .Frequency "2.92" 
     .Create 
End With

'@ define automesh parameters

With Mesh 
     .AutomeshStraightLines "True" 
     .AutomeshEllipticalLines "True" 
     .AutomeshRefineAtPecLines "True", "3" 
     .AutomeshRefinePecAlongAxesOnly "False" 
     .AutomeshAtEllipseBounds "True", "10" 
     .AutomeshAtWireEndPoints "True" 
     .AutomeshAtProbePoints "True" 
     .AutomeshRefineDielectrics "True" 
     .MergeThinPECLayerFixpoints "True" 
     .EquilibrateMesh "False" 
     .UsePecEdgeModel "True" 
     .MeshType "PBA" 
     .AutoMeshLimitShapeFaces "True" 
     .AutoMeshNumberOfShapeFaces "1000" 
End With 
With Solver 
     .UseSplitComponents "True" 
     .PBAFillLimit "99" 
End With

'@ set mesh properties

With Mesh 
     .UseRatioLimit "True" 
     .RatioLimit "50" 
     .LinesPerWavelength "18" 
     .MinimumLineNumber "10" 
     .Automesh "True" 
End With

'@ define solver parameters

With Solver 
     .CalculationType "TD-S" 
     .StimulationPort "All" 
     .StimulationMode "All" 
     .SteadyStateLimit "-60" 
     .MeshAdaption "False" 
     .AutoNormImpedance "False" 
     .NormingImpedance "50" 
     .CalculateModesOnly "False" 
     .SParaSymmetry "False" 
     .StimulationType "Gaussian" 
     .StoreTDResultsInCache "False" 
     .FullDeembedding "False" 
End With

'@ define boundaries

With Boundary
     .Xmin "open" 
     .Xmax "open" 
     .Ymin "open" 
     .Ymax "open" 
     .Zmin "electric" 
     .Zmax "open" 
     .Xsymmetry "magnetic" 
     .Ysymmetry "none" 
     .Zsymmetry "none" 
End With

'@ define solver parameters

With Solver 
     .CalculationType "TD-S" 
     .StimulationPort "All" 
     .StimulationMode "All" 
     .SteadyStateLimit "-50" 
     .MeshAdaption "False" 
     .AutoNormImpedance "False" 
     .NormingImpedance "50" 
     .CalculateModesOnly "False" 
     .SParaSymmetry "False" 
     .StimulationType "Gaussian" 
     .StoreTDResultsInCache "False" 
     .FullDeembedding "False" 
End With 


